#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://pathological.sourceforge.net/
# source           : http://ovh.dl.sourceforge.net/sourceforge/pathological/pathological-1.1.3.tar.gz
# extra boards     : http://pathological.sourceforge.net/contributed-boards-20031004.zip

# Package name
NAME="pathological"
# Package version
VERSION="1.1.3"
# Source code URL
SOURCE="http://ovh.dl.sourceforge.net/sourceforge/pathological/pathological-$VERSION.tar.gz"
# HTML docs URL
HTMLDOCS="http://users.zenwalk.org/user-accounts/gapan/pathological/pathological_html_help-$VERSION.tar.bz2"
# Extra boards URL
EXTRABOARDS="http://pathological.sourceforge.net/contributed-boards-20031004.zip"
# Extra boards version
EXTRABOARDSVERSION="20031004"
# Files that should be placed in /usr/doc/package-version/
DOCS="LICENSE README TODO changelog"
# ./configure options
CONFIGOPTIONS="--prefix=/usr"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="i486"
CPU="i686"
BUILD="48.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: Pathological is an enriched clone of the game "Logical".
$NAME:
$NAME: Pathological is an enriched clone of the game "Logical" by Rainbow
$NAME: Arts. To solve a level, fill each wheel with four marbles of
$NAME: matching color. Various board elements such as teleporters,
$NAME: switches, filters, etc., make the game interesting and challenging.
$NAME: New levels can be created using your favorite text editor.
$NAME:
$NAME:
$NAME:
$NAME:
END

# Create the desktop entry
mkdir -p $PKG/usr/share/applications
cat > $PKG/usr/share/applications/$NAME.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Pathological
Exec=pathological
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=pathological
EOF

# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION
if [ -f $NAME-$VERSION.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Check to see if an icon is present. If it's not, download it
if [ -f $NAME.png ]; then
	echo "Icon file already here, no need to download";
else
 	echo "Downloading icon"
	wget -c http://users.zenwalk.org/user-accounts/gapan/$NAME/$NAME.png
fi

# Check to see if the extra boards are present. If they're not, download them
if [ -f contributed-boards-$EXTRABOARDSVERSION.zip ]; then
	echo "Extra boards already here, no need to download";
else
 	echo "Downloading extra boards"
	wget -c $EXTRABOARDS
fi

# Check to see if the HTML documentation is present. If it's not, download it
if [ -f pathological_html_help-$VERSION.tar.bz2 ]; then
	echo "HTML documentation already here, no need to download";
else
 	echo "Downloading HTML documentation"
	wget -c $HTMLDOCS
fi

# Unpack source
tar xvzf $NAME-$VERSION.tar.gz

# Unpack extra boards
unzip contributed-boards-$EXTRABOARDSVERSION.zip

# Unpack html documentation
tar xvjf pathological_html_help-$VERSION.tar.bz2

# Configure and make
cd $NAME-$VERSION
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
make write-highscores

# Install on temporary directory
# The make install rule in the Makefile needs so much editing, I prefer to do it all manually
mkdir -p $PKG/usr/bin
cp -a pathological $PKG/usr/bin
sed -i -e 's,scoresfile="",scoresfile="pathological_scores",' $PKG/usr/bin/pathological
sed -i -e 's,scoresfile=/var/games/pathological_scores, scoresfile=/usr/share/pathological/pathological_scores,' $PKG/usr/bin/pathological
sed -i -e 's,cd /usr/share/games/pathological,cd /usr/share/pathological,' $PKG/usr/bin/pathological
mkdir -p $PKG/usr/share/pathological
cp -a circuits graphics music sounds pathological.py write-highscores pathological_scores $PKG/usr/share/pathological
sed -i -e 's,write_highscores = "/usr/lib/pathological/bin/write-highscores",write_highscores = "/usr/share/pathological/write-highscores",' $PKG/usr/share/pathological/pathological.py
sed -i -e 's,\xa9,,' $PKG/usr/share/pathological/pathological.py
mkdir -p $PKG/usr/man/man6
cp -a pathological.6.gz $PKG/usr/man/man6

# Copy extra boards to temp install dir
cp -a $CWD/contributed-boards $PKG/usr/share/pathological/circuits

# Copy icon to temp install dir
mkdir -p $PKG/usr/share/icons/hicolor/48x48/apps
cp -a $CWD/$NAME.png $PKG/usr/share/icons/hicolor/48x48/apps

# Strip binaries
cd $PKG
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $CWD/$NAME-$VERSION
cp -a $DOCS $PKG/usr/doc/$NAME-$VERSION
cp -a $CWD/html $PKG/usr/doc/$NAME-$VERSION

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Fix setuid
chmod -R -s $PKG/usr/share/pathological

# But we need the highscores file writable by everyone
chmod a+w $PKG/usr/share/pathological/pathological_scores

# Make the package
makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME-$VERSION
rm -rf $PKG
rm -rf contributed-boards
rm -rf html
